Data Visualization
::::::::::::::::::::::::::::::::

.. toctree::
    :maxdepth: 3

    visualizingdata.rst
    buildinggooglemapfromgeodata.rst
    visualizingnetworksandinterconnections.rst
    visualizingmaildata.rst
    Exercises.rst
    mixedUpCode.rst
